<?php if (! defined('BASEPATH')) exit('No direct script access allowed');


/**
 * Sharethis Extension class for storing global defaults
 *
 * @package   Sharethis
 * @author    Andrew Smiley <andrew@proteanweb.com>
 * @copyright Copyright (c) 2011 Protean Web LLC
 */
class Sharethis_ext {

	var $name = 'EE ShareThis';
	var $version = '1.2.2';
	var $settings_exist = 'y';
	var $docs_url = 'http://proteanweb.com/ee_sharethis_doc.txt';

	/**
	 * Extension Constructor
	 */
	function __construct($settings="")
	{
		$this->EE =& get_instance();

		$this->settings = $settings;
	}

	// --------------------------------------------------------------------

	/**
	 * Activate Extension
	 */
	function activate_extension()
	{
		$this->EE->db->insert('extensions', array(
			'class'    => 'Sharethis_ext',
			'method'   => 'sharethis_get_defaults',
			'hook'     => 'sharethis_get_defaults',
			'settings' => serialize($this->settings),
			'priority' => 10,
			'version'  => $this->version,
			'enabled'  => 'y'
		));
	}
	
	
	function settings()
	{
	    $settings = array();
		
		// JS Initialization Settings
		$settings['js_publisher']          = array('i', '', '');
		$settings['js_load_late']          = array('r', array('yes' => "Yes", 'no' => "No"), 'no');
		$settings['js_classic']            = array('r', array('yes' => "Classic", 'no' => "OAuth"), 'no');
		$settings['js_theme']              = array('s', array('1' => 'Default', '2' => 'Ice', '3' => 'Dust', '4' => 'Pine', '5' => "Da' Bears", '6' => 'Cosmopolitan', '7' => "L' Orange", '8'=>'Silent Movie'), '1');
		$settings['js_ssl']                = array('r', array('yes' => "Yes", 'no' => "No"), 'no');
		$settings['js_script_url']             = array('i', '', 'http://w.sharethis.com/button/buttons.js');
		$settings['js_script_ssl_url']         = array('i', '', 'https://ws.sharethis.com/button/buttons.js');
		$settings['js_tracking']           = array('r', array('yes' => "Yes", 'no' => "No"), 'no');
		$settings['js_publisherGA']        = array('i', '', '');
		$settings['js_doneScreen']         = array('r', array('yes' => "Yes", 'no' => "No"), 'yes');
		$settings['js_onhover']            = array('r', array('yes' => "Yes", 'no' => "No"), 'yes');
		$settings['js_embeds']             = array('r', array('yes' => "Yes", 'no' => "No"), 'no');
		$settings['js_popup']              = array('r', array('yes' => "Yes", 'no' => "No"), 'no');
		$settings['js_callback']           = array('i', '', '');
		$settings['js_offsetLeft']         = array('i', '', '');
		$settings['js_offsetTop']          = array('i', '', '');
		$settings['js_headerTitle']        = array('i', '', '');
		$settings['js_headerColor']        = array('i', '', '');
		$settings['js_headerTextColor']    = array('i', '', '');
		$settings['js_mainWidgetColor']    = array('i', '', '');
		$settings['js_footerColor']        = array('i', '', '');
		$settings['js_serviceBarColor']    = array('i', '', '');
		$settings['js_shareButtonColor']   = array('i', '', '');
		$settings['js_helpTextColor']      = array('i', '', '');
		$settings['js_textBoxFontColor']   = array('i', '', '');


	    // Open Graph Settings
	    $settings['og_site_name']          = array('i', '', $this->EE->config->config['site_name']);
	    $settings['og_title']              = array('i', '', $this->EE->config->config['site_name']);
		$settings['og_type']               = array('i', '', 'article');
		$settings['og_url']                = array('i', '', $this->EE->config->config['site_url']);
		$settings['og_image']              = array('i', '', '');
	    $settings['og_description']        = array('t', array('rows' => '3'), $this->EE->config->config['site_description']);
		

		// Button Settings
		$settings['bt_services']       	   = array('i', '', 'sharethis');
		$settings['bt_display']            = array('s', array('' => 'Default (Small Icon)', 'button' => 'Button', 'large' => 'Large Icon', 'custom'=>'Custom','vcount' => 'Vertical Count', 'hcount' => 'Horizontal Count'), '');
		$settings['bt_text']               = array('i', '', 'Share');
		$settings['bt_content']            = array('i', '', '');
		$settings['bt_title']              = array('i', '', $this->EE->config->config['site_name']);
		$settings['bt_url']                = array('i', '', $this->EE->config->config['site_url']);
		$settings['bt_image']              = array('i', '', '');
		$settings['bt_summary']            = array('t', array('rows' => '2'), '');
		$settings['bt_before']             = array('i', '', '');
		$settings['bt_after']              = array('i', '', '');
		$settings['bt_strip_html']         = array('r', array('yes' => "Yes", 'no' => "No"), 'yes');
		
		$settings['bt_fblike_display']     = array('s', array('fblike'=>'Standard', 'fbLong' => 'Long Button', 'fblike_vcount' => 'Vertical Count', 'fblike_hcount' => 'Horizontal Count'), 'fblike');
		$settings['bt_plusone_display']    = array('s', array('plusone_button' => 'Standard Button', 'plusone' => 'Small Icon', 'plusone_large' => 'Large Icon', 'plusone_vcount' => 'Vertical Count', 'plusone_hcount' => 'Horizontal Count'), '');
	
	    return $settings;
	}


	function sharethis_get_defaults()
	{
		if ($this->EE->session->cache(__CLASS__, 'defaults')){
			return $this->EE->session->cache(__CLASS__, 'defaults');
		}
		
		$defaults = array('js'=>array(),'og'=>array(),'bt'=>array());
		
		foreach($this->settings as $k=>$v){	
			$defaults[substr($k,0,2)][substr($k,3)] = $v;	
		}
		$this->EE->session->set_cache(__CLASS__, 'defaults', $defaults);
		
		return $defaults;	
	}
	
	

	/**
	 * Update Extension
	 *
	 * This function performs any necessary db updates when the extension
	 * page is visited
	 *
	 * @return 	mixed	void on update / false if none
	 */
	function update_extension($current = '')
	{
			
		//nothing to update yet...	
		return FALSE;	
			
		if ($current == '' OR $current == $this->version)
		{
			return FALSE;
		}
		
		if ($current < '1.0')
		{
			// Update to version 1.0
		}
		
		$this->EE->db->where('class', __CLASS__);
		$this->EE->db->update(
					'extensions', 
					array('version' => $this->version)
		);
	}

	/**
	 * Disable Extension
	 *
	 * This method removes information from the exp_extensions table
	 *
	 * @return void
	 */
	function disable_extension()
	{
		$this->EE->db->where('class', __CLASS__);
		$this->EE->db->delete('extensions');
	}


}
