<?php if ( ! defined('BASEPATH')) exit('No direct script access allowed');
/*
========================================================
 
--------------------------------------------------------
 Copyright: Andrew Smiley
 http://proteanweb.com
--------------------------------------------------------
 This addon is commercial software, and a license must
 be purchased for use on each production website domain.
========================================================
 File: pi.sharethis.php
--------------------------------------------------------
 Purpose: Control ShareThis buttons via EE tags
========================================================
 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF
 ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT 
 LIMITED TO THE WARRANTIES OF MERCHANTABILITY, FITNESS
 FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO 
 EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE
 FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
 AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE 
 OR OTHER DEALINGS IN THE SOFTWARE.
=========================================================

*/


$plugin_info = array(
                        'pi_name'			=> 'EE ShareThis',
                        'pi_version'		=> '1.2.2',
                        'pi_author'			=> 'Andrew Smiley',
                        'pi_author_url'		=> 'http://proteanweb.com',
                        'pi_description'	=> 'Control ShareThis buttons via EE tags',
                        'pi_usage'			=>  Sharethis::usage()
                    );


class Sharethis {
	
	var $js, $og, $button, $fblike, $plusone, $defaults, $aliases;

    public function __construct(){
  
        $this->EE =& get_instance();

		$this->js = '<script type="text/javascript">{js}</script>' . NL;
		$this->js_src = '<script type="text/javascript" src="{src}"></script>' . NL;
		
		
		$this->og = '<meta property="{property}" content="{content}" />' . NL;
		
		$this->button = '{before}<span class="st_{service}{display}" st_title="{title}" st_url="{url}" st_image="{image}" st_summary=\'{summary}\' displayText="{text}">{content}</span>{after}';
		
		$this->fblike = '{before}<span class="st{display}" st_url="{url}" st_title="{title}" st_image="{image}" st_summary=\'{summary}\'></span>{after}';
		$this->plusone = str_replace('fblike','plusone',$this->fblike); 

		$this->defaults = $this->EE->extensions->call('sharethis_get_defaults');
		
		$this->aliases = array(
		
							'og' => array(	
										'title'              => 'og:title',
										'type'               => 'og:type',
										'url'                => 'og:url',
										'image'              => 'og:image',
										'description'        => 'og:description'

									),
			
							'js' => array(
										'publisher'	         => 'key',
										'publisherGA'        => 'ga_key',
										'tracking'           => 'ga_tracking',
										'doneScreen'         => array('done_screen','popular_shares'),
										'onhover'            => 'hover',
										'offsetLeft'         => 'offset_left',
										'offsetTop'          => 'offset_top',
										'headerTitle'        => 'header_title',
										'headerColor'        => 'header_color',
										'headerTextColor'    => 'header_text_color',
										'mainWidgetColor'    => 'main_widget_color',
										'footerColor'        => 'footer_color',
										'serviceBarColor'    => 'service_bar_color',
										'shareButtonColor'   => 'share_button_color',
										'helpTextColor'      => 'help_text_color',
										'textBoxFontColor'   => 'textbox_font_color'
									),
									
							'bt' => array(		
										'text'               => 'displayText',
										'services'	         => 'service',
										'before'             => 'prefix',
										'after'              => 'suffix',
										'url'  				 => 'st_url' ,
										'title'              => 'st_title',
										'image'              => 'st_image',
										'summary'            => array('st_summary','description'),
										'content'            => 'tagdata',						
																				
										'plusone_display'    => 'display',
										'fblike_display'     => 'display'						
									)				 
							);							
		
    }
	
	
	function js($autoload = FALSE){
			
		$output = '';
		
		$params = $this->_params('js',array('load_late','ssl','classic','script_url','script_ssl_url','callback'), TRUE);

		extract($params);
		
		$options = array_diff_key($this->_params('js'),$params);

		if ($load_late == 'yes'){
			$output .= str_replace('{js}','var __st_loadLate=true;', $this->js);	
		}
		
		if ($classic != 'yes'){
			
			unset($options['headerfg'],$options['headerbg']);
					
			$output .= str_replace('{js}','var switchTo5x=true;', $this->js);
		}
		
		
		$output .= str_replace('{src}',$ssl == 'yes' ? $script_ssl_url : $script_url,$this->js_src);
				
		$output .= str_replace('{js}', 'stLight.options(' . str_replace(array(':"yes"',':"no"'),array(':true',':false'),json_encode($options)) . ');', $this->js);
		
		if  ($callback){
			$output .= str_replace('{js}', 'stLight.subscribe("click",' . $callback . ');', $this->js);
		}
		
		$this->EE->session->set_cache('Sharethis_ext', 'js_loaded', TRUE);
		
		return $output;
	}
	
	function og(){
		
		$output = '';
	
		foreach($this->_params('og') as $property=>$content){
			if ($content){
				$output .= str_replace(array('{property}','{content}'),array('og:'.$property,$content),$this->og);
			}
		}
		
		return $output;
	}
	
	function button(){
		
		$params = $this->_params('bt');
		
		$params['display'] = $this->_underscore($params['display']);
		
		$services = explode('|',$params['services']);
		
		unset($params['services']);
		
		$output = '';
		foreach($services as $service){
			$output .= $this->_button($params+array('service'=>$service));
		}
		
		return $output;
		
	}

	function fblike(){

		$params = $this->_params('bt');
		
		$params['display'] = $this->_underscore($params['fblike_display']);
			
		return $this->_button($params,$this->fblike);
	}
	
	function plusone(){
		
		$params = $this->_params('bt');
		
		$params['display'] = $this->_underscore($params['plusone_display']);
			
		return $this->_button($params,$this->plusone);
	}
	
	function link(){
		
		$this->EE->load->helper('url');
		
		$params = $this->_params('js',array('publisher')) + $this->_params('bt',array('url','title','image','summary','text'));
		
		$title = $this->EE->TMPL->tagdata ? $this->EE->TMPL->tagdata : $params['text'];
		
	 	return anchor('http://www.sharethis.com/share?'.http_build_query($params),$title,array('target'=>'_blank','title'=>$title));
	}

	
	function _button($params, $haystack = FALSE){
			
		$js = '';
		
		if (!$this->EE->session->cache('Sharethis_ext', 'js_loaded')){
			$js = $this->js();

			$this->EE->session->set_cache('Sharethis_ext', 'js_loaded', TRUE);
		}
		
		if (!$params['summary'] && $this->EE->TMPL->tagdata){
			$params['summary'] = $this->_param('bt','strip_html',TRUE) == 'yes' ? strip_tags($this->EE->TMPL->tagdata) : $this->EE->TMPL->tagdata;
		}
		
			
		$needles = array_keys($params);
		
		array_walk($needles, create_function('&$val','$val = "{".$val."}";'));
			
		return $js . str_replace($needles,$params,$haystack ? $haystack : $this->button);
	}


	
	function _params($type, $params = FALSE, $force_lcase = FALSE){
		
		if (!$params){
			$params = array_keys($this->defaults[$type]);
		}
		
		$parameters = array();
		foreach($params as $param){
			$parameters[$param] = $this->_param($type,$param,$force_lcase);
		}
		
		return $parameters;
	}


	function _param($type, $param, $force_lcase = FALSE){
		
		$not_found = '~NOT FOUND~';
		
		$value = $this->EE->TMPL->fetch_param($param,$not_found);
		
		if ($value == $not_found && isset($this->aliases[$type][$param])){
			
			foreach((array)$this->aliases[$type][$param] as $alias){
					$value = $this->EE->TMPL->fetch_param($alias,$not_found);
					
					if ($value != $not_found){
						break;
					}
			}
		}
		
		if ($value == $not_found){
			$value = isset($this->defaults[$type][$param]) ? $this->defaults[$type][$param] : '';			
		}
		
		
		if ($force_lcase){
			$value  = strtolower($value);
		}
		
		if ($param != 'strip_html' && $this->_param('bt','strip_html',TRUE) == 'yes'){
			$value = strip_tags($value);
		}
		
		
		return $value;
	}

	
	function _underscore($str){
		if (!$str){
			return $str;
		}
		
		return '_'.$str;
	}

	

    /* END */

    
// ----------------------------------------
//  Plugin Usage
// ----------------------------------------

// This function describes how the plugin is used.
//  Make sure and use output buffering

function usage() {
ob_start(); 
?>

This plugin literally supports every aspect of the ShareThis API. An included extension allows for the setting of global defaults, but it not required as every parameter can be overridden at the tag level.  Both the ShareThis native parameter names, as well as more EE-friendly  versions can be used. 

**NOTE** Anytime you upgrade/install ShareThis, it is important that you SAVE THE EXTENSION SETTINGS
or the plugin will not work correctly. **NOTE**

Plugin usage is pretty straight forward, and whatever isn't obvious from the Extension Settings page can be found in the <a href="http://help.sharethis.com/customization/customization-overview">ShareThis Documentation</a>. 

USAGE DETAILS:
------------------------------------------------------------------------------------------------

There are basically three different tags for setting up ShareThis on your page. 

1. The OpenGraph tag allows you to ouput meta tags that control among other things, the title, url, 
and description for your shared content. If you are using ShareThis for Facebook, it is important
you use this OpenGraph tag, because if it is not present, Facebook will simply crawl the page itself
and determine the title, description, image, etc., ignoring whatever parameters you supply for
the ShareThis buttons. THIS IS A LIMITATION OF THE SHARETHIS API/FACEBOOK API and presently this
plugin cannot overcome this, although I welcome ideas. This tag should be used within the head (<head></head>)
of your website. 


2. The second tag is the JS tag for outputting the required javascript that ShareThis needs to
make the buttons work properly. The plugin trys to automatically include the JS if you don't use
this tag explicitly, but it is recommended that you use the tag within your the head (<head></head>)
of your website instead of having the script automatically loaded in the middle of your document.


3. The third tag is the BUTTON tag, along with FBLIKE and PLUSONE. These are used where you'd like
the button(s) to appear.


Many parameters have more than one name, and are separated by commas in the list below.
All parameters, if not included in the tag as an override parameter, default to the global
setting for the extension. Extension global parameter defaults are mentioned when applicable.



Open Graph Tag: {exp:sharethis:og}
------------------------------------------------------------------------------------------------

Parameters:

title, og:title (Defaults to Site Name)

type, og:type (Default="article")

url, og:url (Defaults to Site Url)

image, og:image (Default="")

description, og:description (Default="")


Example: 

{exp:sharethis:og title="My Website" url="http://google.com"}

Produces: (assuming there isn't a global image or description set)
<meta content="My Website" property="og:title" />
<meta content="http://google.com" property="og:url" />
<meta content="article" property="og:type" />


JavaScript Tag: {exp:sharethis:js}
--------------------------------------------------------------------------------------------------
If the js tag isn't included before the first button tag is used, the javascript is 
automatically added based on the extension global defaults.

Parameters:

key,publisher (REQUIRED!!)
The ShareThis publisher key. Of the form xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx

ga_tracking, tracking (Default="no")
Whether to integrate ShareThis stats with google analytics. (yes, no)

ga_key, publisherGA  (Default="")
If ga_tracking is turned on, you can override or specify the GA id here. If left blank,
the first GA id on the page will be used.

load_late (Default="no")
Waits until the page is finished loading to request ShareThis scripts. (yes, no)

classic (Default="no")
Use classic ShareThis dialog instead of the new OAuth version. (yes, no)

theme (Default="1")
The theme NUMBER to use for the OAuth dialog. (1-8)

script_url (Default="http://w.sharethis.com/button/buttons.js")
Url to ShareThis button javascript. Shouldn't ever need to be changed.

ssl (Default="no")
Whether ShareThis should load assets via SSL (yes, no)

script_ssl_url (Default="https://ws.sharethis.com/button/buttons.js")
Secure Url to ShareThis button javascript. Shouldn't ever need to be changed.

embeds (Default="no")
Enable embeddable objects while widget loads (yes, no)

popup (Default="no")
Load ShareThis widgets in popup window

callback (Default="")
Provide a callback function that is called after a user completes a share. See http://help.sharethis.com/customization/callback

done_screen, doneScreen, popular_shares (Default="yes")
Enable Popular Shares screen (yes, no)

hover, onhover (Default="yes")
Display ShareThis widgets on button hover (yes, no)

offset_left, offsetLeft (Default="")
Distance to horizontally offset widget window from widget button

offset_top, offsetTop (Default="")
Distance to vertically offset widget window from widget button



The following parameters ONLY APPLY TO THE OAUTH widged, and will NOT WORK IN CLASSIC MODE.
Color parameters take any valid CSS color property values. (#333,red,rgb(40,40,40) etc.)
See http://help.sharethis.com/customization/colors-and-themes for more info.

header_title, headerTitle (Default="")
Title used in widget header

header_color, headerColor (Default="")
Color of the header

header_text_color, headerTextColor (Default="")
Color of the header text

main_widget_color, mainWidgetColor (Default="")
Background color of the widget

footer_color, footerColor (Default="")
Color of the footer

service_bar_color, serviceBarColor (Default="")
Color of the services/social networks bar

share_button_color, shareButtonColor (Default="")
Color of the "Share" button

help_text_color, helpTextColor (Default="")
Color of the help text

textbox_font_color, textBoxFontColor (Default="")
Color of the font within the textarea.

Example:

{exp:sharethis:js key="xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx" ssl="yes" load_late="yes"}

Produces:

<script type="text/javascript">
	var __st_loadLate=true;
</script>
<script type="text/javascript">
	var switchTo5x=true;
</script>
<script type="text/javascript" src="https://ws.sharethis.com/button/buttons.js"></script>
<script type="text/javascript">
	stLight.options({"publisher":"xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx","theme":"1","tracking":false,"publisherGA":"","doneScreen":true,"onhover":true,"embeds":false,"popup":false,"offsetLeft":"","offsetTop":"","headerTitle":"","headerColor":"","headerTextColor":"","mainWidgetColor":"","footerColor":"","serviceBarColor":"","shareButtonColor":"","helpTextColor":"","textBoxFontColor":""});
</script>



Button Tag: {exp:sharethis:button}
--------------------------------------------------------------------------------------------------

services, service (Default="sharethis")
Pipe Separated list of widgets to display
Popular Services: sharethis, facebook, twitter, reddit
Complete List: http://help.sharethis.com/customization/chicklets

text, displayText (Default="Share")
Text to display inside button when display mode is set to "Button"

before, prefix (Default="")
Content/Markup to include before each button when outputing each service

after, suffix (Default="")
Content/Markup to include after each button when outputting each service

url, st_url (Defaults to Site Url)
The Url associated with the share

title, st_title (Defaults to Site Name)
The Title of the share

image, st_image (Default="")
An image to include with the share

summary, description, st_summary (Defaults to tagdata if tag pair is used, or an empty string))
The Summary text for the share

content, tagdata
Markup to include within the button span tag.

display (Default="" - Default (Small Icon))
The button display type. (button, large, custom, vcount, hcount)
Vertical and Horizontal Count Displays are only supported by ShareThis, Facebook, and Twitter

strip_html
Strips html from the values of the above parameters.


Example:

{exp:sharethis:button services="sharethis|facebook|twitter" title="My page" url="http://google.com"}

Produces:

<span class="st_sharethis" displaytext="Share this" st_summary="" st_image="" st_url="http://google.com" st_title="My page"></span>
<span class="st_facebook" displaytext="Share this" st_summary="" st_image="" st_url="http://google.com" st_title="My page"></span>
<span class="st_twitter" displaytext="Share this" st_summary="" st_image="" st_url="http://google.com" st_title="My page"></span>



Additionally, there are two special tags for Facebook Like and Google Plus buttons

Button Tag: {exp:sharethis:fblike}
--------------------------------------------------------------------------------------------------
Supports all the paramters of the regular button tag, except the "display" parameter has different options

display, plusone_display (Default="hcount")
Display type for facebook like button. (fbLong, vcount, hcount)

Example:

{exp:sharethis:fblike display="hcount" st_title="My Website"}


Produces:

<span st_summary="" st_image="" st_title="My Website" st_url="" class="st_fblike_hcount"></span>



GooglePlus Tag: {exp:sharethis:plusone}
--------------------------------------------------------------------------------------------------
Supports all the paramters of the regular button tag, except the "display" parameter has different options


display, plusone_display (Default="" - Small button)
Display type for google+ button. (button,large,vcount,hcount)


Example:

{exp:sharethis:plusone text="Google Plus!"}

Produces:

<span st_summary="" st_image="" st_title="" st_url="" class="st_plusone"></span>


Non-JS link Tag: {exp:sharethis:link}
--------------------------------------------------------------------------------------------------
Produces a link to take a non-js abled user to the ShareThis page where they can still share content.
Supports the title,summary,image, and url parameters of the regular button tag.

Example:

{exp:sharethis:link}A non js-dependent link to sharethis{/exp:sharethis:link}

Produces:

<a title="A non js-dependent link to sharethis" target="_blank" href="http://www.sharethis.com/share?publisher=xxxxxxxx-xxxx-xxxx-xxxx-xxxxxxxxxxxx&amp;url=&amp;title=&amp;image=&amp;summary=&amp;text=Share+this">A non js-dependent link to sharethis</a>


CHANGELOG:
==========

1.0
Inital release.

1.1
Updated documentation. Cleanup.

1.2
Fixed bug that occurred when automatically outputting sharethis javascript.
Added new display types for FacebookLike button

1.2.1
Fixed bug that prevented the google plusone buttons from displaying properly.

1.2.2
Fixed bug where the autoloading of javascript didn't occur. 
Changed javascript tag parameter name from url and ssl_url, to script_url and script_ssl_url
Added more explicit instructions to documentation


<?php
$buffer = ob_get_contents();
	
ob_end_clean(); 

return $buffer;
}
/* END */


}
/* END Class */
/* End of file pi.sharethis.php */
/* Location: ./system/expressionengine/third_party/sharethis/pi.sharethis.php */